//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================

using System;
using DreamDriven.SoftwareFactory.Components;

namespace DreamDriven.Components.DataSource.EventsArgs
{
	/// <summary>
	/// Provides data for <see cref="DomainObjectDataSource.Updated"/>, <see cref="DomainObjectDataSource.Deleted"/>
	/// and <see cref="DomainObjectDataSource.Inserted"/> events of the the <see cref="DomainObjectDataSource"/> control.
	/// </summary>
    public class DomainObjectDataSourceStatusEventArgs : EventArgs
    {
		/// <summary>
		/// Initializes a new instance of <see cref="DomainObjectDataSourceStatusEventArgs"/>.
		/// </summary>
		/// <param name="instance">The object instance affected by the data operation.</param>
		/// <param name="affectedRows">The number of rows that are affected by the data operation.</param>
        public DomainObjectDataSourceStatusEventArgs(object instance, int affectedRows)
        {
            AffectedRows = affectedRows;
            Instance = instance;
        }
		/// <summary>
		/// Gets the number of rows that are affected by the data operation.
		/// </summary>
        public int AffectedRows { get; private set;}

		/// <summary>
		/// Gets the object instance affected by the data operation.
		/// </summary>
        public object Instance { get; private set;}
    }
}
