﻿using System;
using System.Web;
using System.Web.UI;
using DreamDriven.ObjectModel.Mvp;

namespace DreamDriven.Web
{
    /// <summary>
    /// Represents a page that is a host of views in a Web Forms Model-View-Presenter application
    /// </summary>
    public abstract class BasePage : Page, IViewStateControl
    {        
        /// <summary>
        /// Handles the Error event of the Page.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Error(object sender, EventArgs e)
        {
            Exception ex = Server.GetLastError();
            //ExceptionHandler.Handle(new ExceptionData(ex, "Unexpected exception"));
        }

        /// <summary>
        /// Gets a dictionary of state information that allows you to save and 
        /// restore the view state of a server control across multiple requests for the same page.
        /// </summary>
        /// <value></value>
        /// <returns>An instance of the <see cref="T:System.Web.UI.StateBag"/> class that contains the server control's view-state information.</returns>
        public new StateBag ViewState
        {
            get { return base.ViewState; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="BasePage"/> class.
        /// </summary>
        protected BasePage()
        {
            PresenterBinder.Bind(this);
        }
      
        public string CurrentUserName
        {
            get
            {
                return HttpContext.Current.User.Identity.IsAuthenticated
                           ? HttpContext.Current.User.Identity.Name
                           : string.Empty;
            }
        }
    }
}